@@ -4,7 +4,7 @@ from django_cloud_tasks.management.commands import BaseInitCommand
 
 
 class Command(BaseInitCommand):
-    name = 'subscribers'
+    name = "subscribers"
 
     def perform_init(self, app_config, *args, **options) -> List[str]:
         updated, deleted = app_config.initialize_subscribers()
